@@ -2,8 +2,8 @@
 Used to save and load workflows
 """
 
-from utils.input import import_from_string
-from conf.base import settings
+from percept.utils.input import import_from_string
+from percept.conf.base import settings
 import pickle
 
 class BaseStore(object):
